@@ -68,6 +68,24 @@ class FileExistsTestCase(UCTestCase):
                         "in '/labX' where 'X' is the lab number.")
 
 
+class FileContentsMatchTestCase(UCTestCase):
+    def count_file_matches(self, filename, match, path="/autograder/source/"):
+        """ Count how many time match matches the text in filename """
+
+        try:
+            regexp = re.compile(match, re.MULTILINE)
+        except re.error as _:
+            return -1
+
+        successful_open = False
+        file_contents = ""
+        with open(path + "/" + filename, "r") as file:
+            successful_open = True
+            file_contents = file.read()
+        if not successful_open:
+            return -1
+        return len(regexp.findall(file_contents))
+
 class GoldenTestCase(UCTestCase):
     # Helper methods
     def read_golden(self, filename, path="/autograder/source/"):
